==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/language/1/barnraiser_01/msg_item.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'msg_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_message_subject'] = 					"subject";
$lang['hdr_message_sent'] = 					"sent";


//BODY TEXT
$lang['txt_from'] = 							"from";
$lang['txt_message_size'] = 					"message size";
$lang['txt_reply_help'] = 						"Reply to this message";
$lang['txt_message_type1'] = 					"Click HERE to add this person now!";

?>

==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/language/1/barnraiser_01/msg_item.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'msg_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_message_subject'] = 					"subject";
$lang['hdr_message_sent'] = 					"sent";


//ERRORS
$lang['err_no_friends'] = 						"Sorry, you have no friends to send messages to.";


//SUBMIT BUTTONS
$lang['sub_preview'] = 							"preview";
$lang['sub_edit'] = 							"edit";


//BODY TEXT
$lang['txt_from'] = 							"from";
$lang['txt_message_size'] = 					"message size";
$lang['txt_reply_help'] = 						"Reply to this message";
$lang['txt_message_type1'] = 					"Click HERE to add this person now!";

?>
